@echo off
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
::
:: Make EEPROM firmware
:: Generate an image file 
:: 
:: mkeeprom.bat  <MAC> <Configuration> <Content> <SIZE> [PrmFile]
:: 
:: Example 00-C5-D9-00-00-22 phone1 OEM 11 .\some_prm.inf 
::		   will generate an OEM section only image for 11 bit addressing eeproms
::		   00-C5-D9-00-00-22 coax2 ALL 19 .\some_prm.inf
::		   will generate a full coax image for 19 bit addressing eeproms
::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
:: Cleanup
del /Q tmp\OSEC.HEX >NUL 2>&1
del /Q tmp\MSEC.HEX >NUL 2>&1
del /Q tmp\prm.inf >NUL 2>&1
del /Q tmp\all.inf >NUL 2>&1

call setenv.bat

set rom_size=

if "%1"=="-?" goto USAGE
if "%1"=="-h" goto USAGE
IF .%1==. goto USAGE
IF .%2==. goto ERROR
IF .%3==. goto ERROR
IF .%4==. goto ERROR

:: Copy prm file to some temp directory
IF .%5==. (
	set prm=%PRMINF%
) else (
	set prm=%5
)
if not exist %prm% goto FILE_ERROR
copy %prm% .\tmp\prm.inf >NUL 2>&1

:: for small eeprom we use INF without auto_activate enabled
IF %3==ALL (
	echo auto_activate=1 > tmp\all.inf
	more tmp\prm.inf >> tmp\all.inf	
 	set prm_path=tmp\all.inf
) else (
	set prm_path=tmp\prm.inf
)

:: build OEM section with new MAC address
%mkprm% -M %1 -o -f %prm_path% > tmp\OSEC.HEX 
if %ERRORLEVEL% lss 0 goto PRMFAIL

:: select harware initialization vector file
IF .%2==.phone1 set hw_cfg=%hwpath%\config1.txt
IF .%2==.phone2 set hw_cfg=%hwpath%\config2.txt
IF .%2==.phone4 set hw_cfg=%hwpath%\config4.txt
IF .%2==.phone5 set hw_cfg=%hwpath%\config5.txt
IF .%2==.phone6 set hw_cfg=%hwpath%\config6.txt
IF .%2==.coax1 set  hw_cfg=%hwpath%\config7.txt
IF .%2==.coax2 set  hw_cfg=%hwpath%\config12.txt

IF %4==19 (set rom_size=-B)


IF "%3"=="ALL" goto ALL
IF "%3"=="OEM" goto OEM
goto ERROR

:OEM
:: Link the sections into an image
%mkconf% -Y %rom_size% -o tmp\OSEC.HEX -f eeprom.bin
if %ERRORLEVEL% lss 0 goto CONFFAIL
goto END

:ALL
:: extract the MAC QOS and ADDRESS sections
IF %4==11 goto INVALID_SIZE
%mkprm% -m -f %prm_path% > tmp\MSEC.HEX
if %ERRORLEVEL% lss 0 goto PRMFAIL
%mkprm% -0 -f %prm_path% > tmp\0.HEX
if %ERRORLEVEL% lss 0 goto PRMFAIL
%mkprm% -1 -f %prm_path% > tmp\1.HEX
if %ERRORLEVEL% lss 0 goto PRMFAIL
%mkprm% -2 -f %prm_path% > tmp\2.HEX
if %ERRORLEVEL% lss 0 goto PRMFAIL

:: Link the sections into an image
%mkconf% %rom_size% -Y -o tmp\OSEC.HEX -m tmp\MSEC.HEX -x %xpath%\x1.hex -x %xpath%\x2.hex -x %xpath%\x3.hex -x %xpath%\x4.hex -0 tmp\0.HEX -1 tmp\1.HEX -2 tmp\2.HEX  -i %hw_cfg% -f eeprom.bin
if %ERRORLEVEL% lss 0 goto CONFFAIL
goto END

:ERROR
echo ERROR - Invalid input!
goto USAGE

:INVALID_SIZE
echo You cannot program complete image on a small eeporm!
goto END

:PRMFAIL
@echo Failed to process parameters
goto END

:CONFFAIL
@echo Failed to generate image file
goto END

:FILE_ERROR
@echo Failed to find parameter file %5
goto END

:USAGE
@echo.
@echo Usage: "mkeeprom.bat <MAC> <Configuration> <Content> <SIZE> [PrmFile]"
@echo.
@echo   MAC     - Mac address to set into image e.g: 00-C5-D9-00-00-22
@echo   ConfID  - Hardware configuration 
@echo             Available Cfg: phone1, phone2, phone4, phone5, phone6, coax1, coax2 
@echo   Content - OEM or ALL
@echo   SIZE 	- 11 or 19
@echo   PrmFile - Full/Relative path to prm file (OPTIONAL - default: ..\fwtool\prm.inf)
@echo.
goto END

:END
:: Cleanup
del /Q tmp\OSEC.HEX >NUL 2>&1
del /Q tmp\MSEC.HEX >NUL 2>&1
del /Q tmp\prm.inf >NUL 2>&1
del /Q tmp\all.inf >NUL 2>&1
